==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/AgConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.AgConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Availability group configuration.
 * @property replicas Replica configurations.
 */
public data class AgConfigurationArgs(
    public val replicas: Output<List<AgReplicaArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.AgConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.AgConfigurationArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.AgConfigurationArgs.builder()
            .replicas(
                replicas?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AgConfigurationArgs].
 */
@PulumiTagMarker
public class AgConfigurationArgsBuilder internal constructor() {
    private var replicas: Output<List<AgReplicaArgs>>? = null

    /**
     * @param value Replica configurations.
     */
    @JvmName("mfgvxyoxlypqejvp")
    public suspend fun replicas(`value`: Output<List<AgReplicaArgs>>) {
        this.replicas = value
    }

    @JvmName("njkbmmkmtmmxlhwq")
    public suspend fun replicas(vararg values: Output<AgReplicaArgs>) {
        this.replicas = Output.all(values.asList())
    }

    /**
     * @param values Replica configurations.
     */
    @JvmName("bchycqqxfrqbrusk")
    public suspend fun replicas(values: List<Output<AgReplicaArgs>>) {
        this.replicas = Output.all(values)
    }

    /**
     * @param value Replica configurations.
     */
    @JvmName("rtceldbakffwavbc")
    public suspend fun replicas(`value`: List<AgReplicaArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replicas = mapped
    }

    /**
     * @param argument Replica configurations.
     */
    @JvmName("cpxstxgthtxabydo")
    public suspend fun replicas(argument: List<suspend AgReplicaArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { AgReplicaArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.replicas = mapped
    }

    /**
     * @param argument Replica configurations.
     */
    @JvmName("vacwtwihemfwwnjy")
    public suspend fun replicas(vararg argument: suspend AgReplicaArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { AgReplicaArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.replicas = mapped
    }

    /**
     * @param argument Replica configurations.
     */
    @JvmName("loqdkkrborsmbvdp")
    public suspend fun replicas(argument: suspend AgReplicaArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AgReplicaArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.replicas = mapped
    }

    /**
     * @param values Replica configurations.
     */
    @JvmName("ghrpjthvcddmqbuq")
    public suspend fun replicas(vararg values: AgReplicaArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replicas = mapped
    }

    internal fun build(): AgConfigurationArgs = AgConfigurationArgs(
        replicas = replicas,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/AgConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.AgConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Availability group configuration.
 * @property replicas Replica configurations.
 */
public data class AgConfigurationArgs(
    public val replicas: Output<List<AgReplicaArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.AgConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.AgConfigurationArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.AgConfigurationArgs.builder()
            .replicas(
                replicas?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AgConfigurationArgs].
 */
@PulumiTagMarker
public class AgConfigurationArgsBuilder internal constructor() {
    private var replicas: Output<List<AgReplicaArgs>>? = null

    /**
     * @param value Replica configurations.
     */
    @JvmName("pfyoalvxtxoaswqo")
    public suspend fun replicas(`value`: Output<List<AgReplicaArgs>>) {
        this.replicas = value
    }

    @JvmName("qpvabkafcaakslft")
    public suspend fun replicas(vararg values: Output<AgReplicaArgs>) {
        this.replicas = Output.all(values.asList())
    }

    /**
     * @param values Replica configurations.
     */
    @JvmName("jtjmynnyllgsenfa")
    public suspend fun replicas(values: List<Output<AgReplicaArgs>>) {
        this.replicas = Output.all(values)
    }

    /**
     * @param value Replica configurations.
     */
    @JvmName("kcjdbthjifdmeley")
    public suspend fun replicas(`value`: List<AgReplicaArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replicas = mapped
    }

    /**
     * @param argument Replica configurations.
     */
    @JvmName("sscsaqdknighxwrb")
    public suspend fun replicas(argument: List<suspend AgReplicaArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { AgReplicaArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.replicas = mapped
    }

    /**
     * @param argument Replica configurations.
     */
    @JvmName("nnwsxxkxcmkflxln")
    public suspend fun replicas(vararg argument: suspend AgReplicaArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { AgReplicaArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.replicas = mapped
    }

    /**
     * @param argument Replica configurations.
     */
    @JvmName("ychiejkhnklvprat")
    public suspend fun replicas(argument: suspend AgReplicaArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AgReplicaArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.replicas = mapped
    }

    /**
     * @param values Replica configurations.
     */
    @JvmName("gipojqdjmrpupgrv")
    public suspend fun replicas(vararg values: AgReplicaArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replicas = mapped
    }

    internal fun build(): AgConfigurationArgs = AgConfigurationArgs(
        replicas = replicas,
    )
}
